diff

Function diff 

pub fn diff(old: &Projection, new: &Projection, context: usize) -> Vec<Hunk>
Diffs two projections line by line and groups the result into hunks with context unchanged lines around each change.