inline_changes

Function inline_changes 

pub fn inline_changes(old: &str, new: &str) -> Option<(Marks, Marks)>
The parts of two versions of a line that differ, compared token by token, or None when the lines have too little in common for highlighting the difference to help.