pub struct EditorCommand {
pub program: String,
pub args: Vec<String>,
pub in_terminal: bool,
}Expand description
How to open a file at a line in the user’s editor.
Fields
program: Stringargs: Vec<String>in_terminal: boolThe editor runs in this terminal, so the viewer must step aside until it exits.