pub struct FileReview {
pub path: String,
pub old_path: Option<String>,
pub status: ChangeStatus,
pub detection: Detection,
pub is_test: bool,
pub fingerprint: u64,
/* private fields */
}Expand description
A changed file. Its diff under each choice of layers is computed on first use.
Fields
path: Stringold_path: Option<String>status: ChangeStatusdetection: Detectionis_test: boolThe whole file is test code; the test layer is file-granular.
fingerprint: u64Identifies this exact change (path and both versions) for review marks.
Implementations
Sourceimpl FileReview
impl FileReview
pub fn new(change: FileChange) -> FileReview
pub fn view(&self, modes: impl Into<DiffModes>) -> Rc<ModeView>
pub fn total_hunks(&self) -> usize
Sourcepub fn is_visible(&self, tests: LayerMode) -> bool
pub fn is_visible(&self, tests: LayerMode) -> bool
Whether the file is listed at all under this test-layer mode.