pub fn github_comment(
pr: &PullRequest,
note: &Note,
head: &str,
on_file: bool,
) -> Vec<String>Expand description
The gh api arguments that comment on the note’s line at the PR’s head commit, or,
with on_file, on the file as a whole with the line named in the text.