Structs
- Editor
Command - How to open a file at a line in the user’s editor.
Functions
- editor_
command - Builds the command for
editor(the value of$VISUALor$EDITOR, which may carry its own arguments, likecode --wait), or the system opener when none is set.