pub fn annotate(projection: &mut Projection, lang: Lang)Expand description
Colours a projection by highlighting its own text, so what is coloured is exactly what is shown — comments removed, or only comments — not the original file.
pub fn annotate(projection: &mut Projection, lang: Lang)Colours a projection by highlighting its own text, so what is coloured is exactly what is shown — comments removed, or only comments — not the original file.